@@ -5,7 +5,7 @@ package Lemonldap::NG::Handler::PSGI::Main;
 
 use strict;
 use base 'Lemonldap::NG::Handler::Main';
-our $VERSION = '2.0.6';
+our $VERSION = '2.19.0';
 
 # Specific modules and constants for Test or CGI
 use constant FORBIDDEN         => 403;
@@ -107,6 +107,49 @@ sub cgiName {
     return "HTTP_$h";
 }
 
+sub logout_app {
+    my $class = shift;
+    my $u     = shift;
+    $class->logger->debug("Nginx logout_app redirect to $u");
+    return (
+        sub {
+            my ( $req, $session ) = @_;
+            my $dest = $u || $class->tsv->{portal}->($req);
+            $class->logger->debug(
+"logout_app_sso: sending internal_lemonldap_logout_url with $dest"
+            );
+            $class->set_header_out( $req,
+                ( "internal_lemonldap_logout_url" => "$dest" ) );
+            1;
+        },
+        0
+    );
+}
+
+sub logout_app_sso {
+    my $class = shift;
+    my $u     = shift;
+    $class->logger->debug("Nginx logout_app_sso redirect to $u");
+    return (
+        sub {
+            my ( $req, $session ) = @_;
+            $class->localUnlog( $req, @_ );
+            my $portal = $class->tsv->{portal}->($req);
+            my $dest   = $u || $portal;
+            my $rurl =
+                $portal . "?url="
+              . $class->encodeUrl( $req, $dest )
+              . "&logout=1";
+            $class->logger->debug(
+                "logout_app: sending internal_lemonldap_logout_url with $rurl");
+            $class->set_header_out( $req,
+                ( "internal_lemonldap_logout_url" => "$rurl" ) );
+            1;
+        },
+        0
+    );
+}
+
 *setPostParams = *addToHtmlHead;
 
 1;
